.. _require_system_module:

:mod:`fabtools.require.system`
------------------------------

.. automodule:: fabtools.require.system

    .. seealso:: :ref:`system_module`

    .. autofunction:: hostname
    .. autofunction:: sysctl

    Locales
    ~~~~~~~

    .. autofunction:: default_locale
    .. autofunction:: locale
    .. autofunction:: locales
